==> one_time_login_link_admin-1.0.6.zip: one_time_login_link_admin/src/Controller/OneTimeLoginLinkController.php <==
<?php

/**
 * @file
 * This file is used to write the code to generate the login link in the module.
 */

namespace Drupal\one_time_login_link_admin\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Datetime\DateFormatter;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines OneTimeLoginLinkController Class.
 *
 * @package Drupal\one_time_login_link_admin\Controller
 */
class OneTimeLoginLinkController extends ControllerBase {

  /**
   * Date time formatter service.
   *
   * @var Drupal\Core\Datetime\DateFormatter
   */
  protected $dateFormatter;

  /**
   * Constructs the service objects.
   */
  public function __construct(DateFormatter $date_formater) {
    $this->dateFormatter = $date_formater;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('date.formatter'),
    );
  }

  /**
   * Generates a one-time login (password reset) link for the given user.
   *
   * @param \Drupal\Core\Session\AccountInterface $user
   *   The user for which to generate the login link.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse|null
   *   A redirect to the destination, if one was provided.
   */
  public function generateLoginLink(AccountInterface $user) {
    $timeout = $this->config('user.settings')->get('password_reset_timeout');
    $url = user_pass_reset_url($user);
    $mail = $user->getEmail();
    $this->messenger()->addMessage($this->t('One-time login link created for %mail:<br/> <code>%login</code>', [
      '%mail' => $mail,
      '%login' => $url,
    ]));

    $this->messenger()->addMessage($this->t("This link is valid for %hr, and will become invalid if the user's password is updated by anyone.", [
      '%hr' => $this->dateFormatter->formatInterval($timeout),
    ]));

    if ($destination = $this->getRedirectDestination()->get()) {
      return new RedirectResponse($destination);
    }
  }

}

==> one_time_login_link_admin-1.0.7.zip: one_time_login_link_admin/src/Controller/OneTimeLoginLinkController.php <==
<?php

/**
 * @file
 * This file is used to write the code to generate the login link in the module.
 */

namespace Drupal\one_time_login_link_admin\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Session\AccountInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Datetime\DateFormatter;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines OneTimeLoginLinkController Class.
 *
 * @package Drupal\one_time_login_link_admin\Controller
 */
class OneTimeLoginLinkController extends ControllerBase {

  /**
   * Date time formatter service.
   *
   * @var Drupal\Core\Datetime\DateFormatter
   */
  protected $dateFormatter;

  /**
   * Constructs the service objects.
   */
  public function __construct(DateFormatter $date_formater) {
    $this->dateFormatter = $date_formater;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('date.formatter'),
    );
  }

  /**
   * Generates a one-time login (password reset) link for the given user.
   *
   * @param \Drupal\Core\Session\AccountInterface $user
   *   The user for which to generate the login link.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse|null
   *   A redirect to the destination, if one was provided.
   */
  public function generateLoginLink(AccountInterface $user) {
    $timeout = $this->config('user.settings')->get('password_reset_timeout');
    // Adding "/login" to the Drupal-supplied one-time login link removes one
    // step from the process: instead of users having to click "Log in" on an
    // unnecessary intermediate screen, log them in directly.
    $url = user_pass_reset_url($user) . '/login';
    $mail = $user->getEmail();
    $this->messenger()->addMessage($this->t('One-time login link created for %mail:<br/> <code>%login</code>', [
      '%mail' => $mail,
      '%login' => $url,
    ]));

    $this->messenger()->addMessage($this->t("This link is valid for %hr, and will become invalid if the user's password is updated by anyone.", [
      '%hr' => $this->dateFormatter->formatInterval($timeout),
    ]));

    if ($destination = $this->getRedirectDestination()->get()) {
      return new RedirectResponse($destination);
    }
  }

}
